@@ -8,7 +8,7 @@ use CGI();
 BEGIN {
     use Exporter ();
     use vars qw($VERSION @ISA @EXPORT @EXPORT_OK %EXPORT_TAGS);
-    $VERSION     = '0.20';
+    $VERSION     = '0.21';
     @ISA         = qw(Exporter);
     #Give a hoot don't pollute, do not export more than needed by default
     @EXPORT      = qw();
@@ -244,7 +244,7 @@ provides OptimalQuery a connection to the database.
 
 Default fields to show user when loading OptimalQuery the first time. This can also be set as a CGI param where the value is a comma separated list of column aliases. Example: "[NAME], [DOB]".
 
-=item B<< params => { show => "COLALIAS1,COLALIAS2", filter => "[COLALIAS1]=5", sort => "[COLALIAS1]", queryDescr => "descr here", hiddenFilter => "[COLALIAS1]=5" }
+=item B<< params => { show => "COLALIAS1,COLALIAS2", filter => "[COLALIAS1]=5", sort => "[COLALIAS1]", queryDescr => "descr here", hiddenFilter => "[COLALIAS1]=5" } >>
 
 Get user set parameters from this hash instead of CGI params. Useful if you are constructing an OQ that should not be influenced by CGI params.
 
@@ -276,20 +276,31 @@ The following KEY/VALUES below describe OPTIONS used by the select configuration
 
 =over
 
-=item B<< select => [COLALIAS1, COLALIAS2]
-=item B<< select => "COLALIAS1, COLALIAS2"
+=item B<< select => [COLALIAS1, COLALIAS2] >>
+
+=item B<< select => "COLALIAS1, COLALIAS2" >>
 
 Define other select fields to be included in executed SQL. These fields can be used in custom formatters including the built in CGI::OptimalQuery::Base::recview_formatter.
 
-=item B<< formatter => sub { my ($val, $rec, $o, $colAlias) = @_; return $val; } >>
-=item B<< html_formatter => sub { my ($val, $rec, $o, $colAlias) = @_; return $val; } >>
+=item B<< formatter => CODEREF >>
 
-Override the default function that is used to output a field value.
+sub {
+  my ($val, $rec, $o, $colAlias) = @_;
+  return $val;
+}
 
-=item B<< formatter => \&CGI::OptimalQuery::Base::recview_formatter
-=item B<< html_formatter => \&CGI::OptimalQuery::Base::recview_html_formatter
+# Built in formatters to display all field/values specified in 'select' as text.
+\&CGI::OptimalQuery::Base::recview_formatter
 
-Built in formatters to display all field/values specified in 'select'.
+=item B<< html_formatter => CODEREF >>
+
+sub {
+  my ($val, $rec, $o, $colAlias) = @_;
+  return $val;
+}
+
+# Built in formatters to display all field/values specified in 'select' as html.
+\&CGI::OptimalQuery::Base::recview_html_formatter
 
 =item B<< is_hidden => 1 >>
 
