@@ -418,6 +418,7 @@ if (! window._OQAjaxQueryLoaded)
     if (fieldIdx === '') fieldIdx = -1;
     var newshow = show.splice(0,fieldIdx + 1);
     $panel.find('input:checked').each(function(){ newshow.push(this.value); });
+    $f[0].mode.value=$("#ShowColumnsDisplayAs").val();
     $show.val(newshow.concat(show).join(','));
     $f.children('.OQAddColumnsPanel').remove();
     $f.removeClass('OQAddColumnsMode');
@@ -700,13 +701,8 @@ if (! window._OQAjaxQueryLoaded)
       var $f = $filterpanel.closest('form');
       var dat = buildParamMap($f);
       dat.filter = createFilterStr($filterpanel);
-      if (dat.filter.toLowerCase().replace(/\s/g,'') ==
-        $f[0].filter.value.toLowerCase().replace(/\s/g,'')) {
-        $filterpanel.find('button.CancelFilterBut').click();
-      } else {
-        delete dat.page; delete dat.rows_page;
-        refreshDataGrid($f,dat);
-      }
+      delete dat.page; delete dat.rows_page;
+      refreshDataGrid($f,dat);
     }
     return true;
   });
